#
# spec file for package read-only-root-fs
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           read-only-root-fs
Version:        1.0+git20200730.1243fd0
Release:        lp152.mo.1.1
Summary:        Files and Scripts for a RO root fileystem
License:        GPL-2.0-or-later
Group:          System/Fhs
URL:            https://github.com/openSUSE/read-only-root-fs
Source:         read-only-root-fs-%{version}.tar.xz
Source1:        README.packaging.txt
BuildRequires:  dracut
BuildRequires:  update-bootloader-rpm-macros
Requires:       dracut
Requires(post): /usr/bin/mkdir /usr/bin/cat /usr/bin/sed
Requires(post): gawk
Requires(post): snapper
# Required if system with new /etc/fstab entries is supposed to be updated
Conflicts:      transactional-update < 2.15
BuildArch:      noarch
%{update_bootloader_requires}

%description
Files, scripts and directories to run the system with a
read-only root filesystem with %{_sysconfdir} writeable via overlayfs.

This package should never be installed in an already running
system! It should only be selected by a system role for a
read-only root filesystem with transactional updates.
The package will create / modify entries for mounting /etc and /var.
Those entries are used by dracut to mount the overlay file systems
during the early boot phase.

%package volatile
Summary:        Dracut Module to mount a tmpfs overlay on a RO root
Group:          System/Fhs
Requires:       dracut

%description volatile
A dracut module which mounts an overlayfs each on /etc and /var, with the upper
layer in a tmpfs mount. This is the minimal setup to get a booting system, to
have a writable /root or /home, additional fstab entries can be added.

%prep
%setup -q

%build

%install
cp -a etc usr %{buildroot}
mkdir -p %{buildroot}%{_localstatedir}/lib/overlay/work-etc

%post
if [ "$1" = 1 ] ; then
    %{_sbindir}/setup-fstab-for-overlayfs
    mkdir -p %{_localstatedir}/lib/overlay/1/etc
fi
if [ ! -e /boot/writable -a "`findmnt -n -o FSTYPE -l /`" = "btrfs" ]; then
    %{_sbindir}/mksubvolume /boot/writable
fi
%{?update_bootloader_refresh_post}

%posttrans
if [ -f %{_sysconfdir}/zypp/zypp.conf ]; then
    sed -i 's/^multiversion =.*/multiversion =/g' %{_sysconfdir}/zypp/zypp.conf
fi
%{?update_bootloader_posttrans}
exit 0

%files
%license COPYING
%{_sbindir}/setup-fstab-for-overlayfs
%{_localstatedir}/lib/overlay
%{_prefix}/lib/dracut/dracut.conf.d/10-read-only-root-fs.conf
%{_prefix}/lib/systemd/system-preset/*
%dir %{_prefix}/lib/systemd/system/systemd-udevd.service.d
%{_prefix}/lib/systemd/system/systemd-udevd.service.d/etcmount.conf
%dir %{_prefix}/lib/systemd/system/systemd-journal-flush.service.d
%{_prefix}/lib/systemd/system/systemd-journal-flush.service.d/afterlocalfs.conf
%dir %{_sysconfdir}/grub.d
%config(noreplace) %{_sysconfdir}/grub.d/01_suse_ro_root

%files volatile
%license COPYING
%{_prefix}/lib/dracut/modules.d/99volatile-overlay/

%changelog
* Thu Jul 30 2020 iforster@suse.com
- Update to version 1.0+git20200730.1243fd0:
  * Add comment about the mounting of /root in the initrd
  * Better check for already existing /etc overlay [boo#1174733]
* Tue Jul 21 2020 Thorsten Kukuk <kukuk@suse.com>
- Use file requires, add sed
* Tue Jan 21 2020 iforster@suse.com
- Update to version 1.0+git20200121.5ed8d15:
  * Always mount /root during initrd [boo#1161264]
* Tue Dec  3 2019 opensuse-packaging@opensuse.org
- Update to version 1.0+git20191203.3f7cc07:
  * Workaround /var being RO during systemd-journal-flush (boo#1156421)
* Tue Nov 12 2019 kukuk@suse.com
- Update to version 1.0+git20191112.42add9e:
  * Add RequiresMountsFor=/etc override for systemd-udevd.service
* Fri Jun  7 2019 iforster@suse.com
- Update to version 1.0+git20190607.11f8587:
  * Determine /@ programmatically
* Thu Jun  6 2019 iforster@suse.com
- Update to version 1.0+git20190606.e1f756c:
  * Mount writable /boot subvolume in GRUB environment
- Create /boot/writable subvolume to provide a place to store the
  GRUB environment block or Ignition's firstboot flag on a ro root
  device
* Wed Feb  6 2019 iforster@suse.com
- Update description to reflect new behaviour
- Fix creation of overlay directories
* Wed Feb  6 2019 kukuk@suse.de
- Fix file list
* Wed Feb  6 2019 fvogt@suse.com
- Update to version 1.0+git20190206.586e9f1:
  * Remove migration code, only handle the initial setup here
  * Drop use of fstab.sys
  * Use a dracut config file instead of a module
* Wed Jun  6 2018 kukuk@suse.de
- Update to version 1.0+git20180606.046b099:
  * Fix missing shebang
  * Make scripts executeable
  * Enable create-dirs-from-rpmdb.service by default
* Wed Apr 18 2018 fvogt@suse.com
- Update to version 1.0+git20180418.4373cf9:
  * Fix 99volatile-overlay
  * proper shell escaping in mount-overlay.sh (#3)
* Mon Apr 16 2018 fvogt@suse.com
- Update to version 1.0+git20180416.825ad6c:
  * Add new 99volatile-overlay dracut module
- BuildRequire/Require dracut for proper directory ownership
- Fix posttrans if zypper is not installed
* Wed Mar 21 2018 kukuk@suse.de
- Disable multiversion feature of libzypp at install time
- Document, that this package should never be installed in a
  running system, only during installation
* Wed Mar 21 2018 kukuk@suse.de
- Update to version 1.0+git20180321.a5b34ab:
  * Disable purge-kernels.service, does not work with read-only
    root filesystem
  * Enable man-db-create.service, man cannot create cache in %%post
  * Fix OBS URL
* Fri Mar  2 2018 rbrown@suse.com
- Add Requires(post) for coreutils & grep to ensure post script has
  what it needs (boo#1083526)
* Tue Feb 27 2018 kukuk@suse.de
- Update to version 1.0+git20180227.44d5e8a:
  * Initial import of read-only-root-fs stuff from caasp-tools
* Tue Feb 27 2018 kukuk@suse.de
- Initial version
